Whether or not #PaulLeRoux invented #Bitcoin is an interesting question but even if he didn't, the design and politics of #TrueCrypt finally provide an answer to that ancient question:

If a brutal international crime kingpin had the skills and the knowledge to design an encryption system to protect him from the FBI/CIA/FSB/Mossad/everyone, how would he design it?
